@@ -53,17 +53,19 @@ De-embedding Methods
 
 """
 
-from abc import ABC, abstractmethod
-from ..frequency import *
-from ..network import *
 import warnings
+from abc import ABC, abstractmethod
+
 import numpy as np
-from numpy import concatenate, conj, flip, real, angle, exp, zeros
-from numpy.fft import fft, fftshift, irfft, ifftshift
+from numpy import angle, concatenate, conj, exp, flip, real, zeros
+from numpy.fft import fft, fftshift, ifftshift, irfft
 from scipy.interpolate import interp1d
 
+from ..frequency import Frequency
+from ..network import Network, concat_ports, overlap_multi, subnetwork
 from ..util import subplots
 
+
 class Deembedding(ABC):
     """
     Abstract Base Class for all de-embedding objects.
@@ -107,7 +109,8 @@ class Deembedding(ABC):
        # ensure all the dummy Networks' frequency's are the same
         for dmyntwk in dummies:
             if dummies[0].frequency != dmyntwk.frequency:
-                warnings.warn('Dummy Networks dont have matching frequencies, attempting overlap.', RuntimeWarning)
+                warnings.warn('Dummy Networks dont have matching frequencies, attempting overlap.', RuntimeWarning,
+                              stacklevel=2)
                 dummies = overlap_multi(dummies)
                 break
 
@@ -123,9 +126,8 @@ class Deembedding(ABC):
         else:
             name = self.name
 
-        output = '%s Deembedding: %s, %s, %s dummy structures'\
-                %(self.__class__.__name__, name, str(self.frequency),\
-                    len(self.dummies))
+        output = (f'{self.__class__.__name__} Deembedding: {name}, {self.frequency}, '
+                  f'{len(self.dummies)} dummy structures')
 
         return output
 
@@ -236,7 +238,8 @@ class OpenShort(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.open.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning,
+                          stacklevel=2)
             caled, op, sh = overlap_multi([ntwk, self.open, self.short])
         else:
             caled, op, sh = ntwk.copy(), self.open, self.short
@@ -329,7 +332,8 @@ class Open(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.open.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning,
+                           stacklevel=2)
             ntwk, op = overlap_multi([ntwk, self.open])
         else:
             op = self.open
@@ -427,7 +431,8 @@ class ShortOpen(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.open.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning,
+                          stacklevel=2)
             ntwk, op, sh = overlap_multi([ntwk, self.open, self.short])
         else:
             op, sh = self.open, self.short
@@ -523,7 +528,8 @@ class Short(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.short.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning,
+                           stacklevel=2)
             ntwk, sh = overlap_multi([ntwk, self.short])
         else:
             sh = self.short
@@ -617,7 +623,8 @@ class SplitPi(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.thru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, thru = overlap_multi([ntwk, self.thru])
         else:
             thru = self.thru
@@ -717,7 +724,8 @@ class SplitTee(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.thru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, thru = overlap_multi([ntwk, self.thru])
         else:
             thru = self.thru
@@ -820,7 +828,8 @@ class AdmittanceCancel(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.thru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, thru = overlap_multi([ntwk, self.thru])
         else:
             thru = self.thru
@@ -921,7 +930,8 @@ class ImpedanceCancel(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.thru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, thru = overlap_multi([ntwk, self.thru])
         else:
             thru = self.thru
@@ -1077,7 +1087,8 @@ class IEEEP370_SE_NZC_2xThru(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.s2xthru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, s2xthru = overlap_multi([ntwk, self.s2xthru])
             s_side1, s_side2 = self.split2xthru(s2xthru)
         else:
@@ -1156,7 +1167,7 @@ class IEEEP370_SE_NZC_2xThru(Deembedding):
             if(f[0] == 0):
                 warnings.warn(
                     "DC point detected. An interpolated DC point will be included in the errorboxes.",
-                    RuntimeWarning
+                    RuntimeWarning, stacklevel=2
                     )
                 flag_DC = True
                 f = f[1:]
@@ -1167,13 +1178,12 @@ class IEEEP370_SE_NZC_2xThru(Deembedding):
             # interpolate S-parameters if the frequency vector is not acceptable
             if(f[1] - f[0] != f[0]):
                 warnings.warn(
-                   """Non-uniform frequency vector detected. An interpolated S-parameter matrix will be created for this calculation.
-                   The output results will be re-interpolated to the original vector.""",
-                   RuntimeWarning
+                   """Non-uniform frequency vector detected. An interpolated S-parameter matrix will be created for
+                   this calculation. The output results will be re-interpolated to the original vector.""",
+                   RuntimeWarning, stacklevel=2
                    )
                 flag_df = True
                 f_original = f
-                df = f[1] - f[0]
                 projected_n = round(f[-1]/f[0])
                 if(projected_n <= 10000):
                     fnew = f[0] * (np.arange(0, projected_n) + 1)
@@ -1282,12 +1292,12 @@ class IEEEP370_SE_NZC_2xThru(Deembedding):
             e01 = np.sqrt(s21r * (1 - e111 * e112))
             for i in range(n):
                 if i > 0:
-                    if npy.abs(-e01[i] - e01[i-1]) < npy.abs(e01[i] - e01[i-1]):
+                    if np.abs(-e01[i] - e01[i-1]) < np.abs(e01[i] - e01[i-1]):
                         e01[i] = - e01[i]
             e10 = np.sqrt(s12r * (1 - e111 * e112))
             for i in range(n):
                 if i > 0:
-                    if npy.abs(-e10[i] - e10[i-1]) < npy.abs(e10[i] - e10[i-1]):
+                    if np.abs(-e10[i] - e10[i-1]) < np.abs(e10[i] - e10[i-1]):
                         e10[i] = - e10[i]
 
 
@@ -1562,7 +1572,8 @@ class IEEEP370_MM_NZC_2xThru(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.s2xthru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, s2xthru = overlap_multi([ntwk, self.s2xthru])
             se_side1, se_side2 = self.split2xthru(s2xthru)
         else:
@@ -1785,7 +1796,8 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.s2xthru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, s2xthru = overlap_multi([ntwk, self.s2xthru])
             s_side1, s_side2 = self.split2xthru(s2xthru,
                                                       self.sfix_dut_fix)
@@ -1883,10 +1895,12 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
         # todo: use DefinedGammaZ0 media instead
         n = len(gamma)
         TL = np.zeros((n, 2, 2), dtype = complex)
-        TL[:, 0, 0] = ((zline**2 - z0**2) * np.sinh(gamma * l)) / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l))
+        TL[:, 0, 0] = (((zline**2 - z0**2) * np.sinh(gamma * l))
+                       / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l)))
         TL[:, 1, 0] = (2 * z0 * zline) / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l))
         TL[:, 0, 1] = (2 * z0 * zline) / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l))
-        TL[:, 1, 1] = ((zline**2 - z0**2) * np.sinh(gamma * l)) / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l))
+        TL[:, 1, 1] = (((zline**2 - z0**2) * np.sinh(gamma * l))
+                       / ((zline**2 + z0**2) * np.sinh(gamma * l) + 2 * z0 * zline * np.cosh(gamma * l)))
         return TL
 
     def NRP(self, nin, TD = None, port = None):
@@ -2080,7 +2094,9 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
             # abcd_TL2 = sTL2.a
             # abcd_in  = s_dut.a
             # for j in range(len(s_dut.frequency.f)):
-            #     abcd_in[j, :, :] = np.linalg.lstsq(abcd_TL1[j, :, :].T, np.linalg.lstsq(abcd_TL1[j, :, :], abcd_in[j, :, :], rcond=None)[0].T, rcond=None)[0].T
+            #     abcd_in[j, :, :] = np.linalg.lstsq(abcd_TL1[j, :, :].T,
+            #                                        np.linalg.lstsq(abcd_TL1[j, :, :], abcd_in[j, :, :],
+            #                                        rcond=None)[0].T, rcond=None)[0].T
             # s_dut.a = abcd_in
             s11dut = s_dut.s[:, 0, 0]
             s22dut = s_dut.s[:, 1, 1]
@@ -2153,7 +2169,7 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
         if(f[0] == 0):
             warnings.warn(
                 "DC point detected. The included DC point will not be used during extraction.",
-                RuntimeWarning
+                RuntimeWarning, stacklevel=2
                 )
             self.flag_DC = True
             f = f[1:]
@@ -2168,7 +2184,7 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
             warnings.warn(
                """Non-uniform frequency vector detected. An interpolated S-parameter matrix will be created for
                this calculation. The output results will be re-interpolated to the original vector.""",
-               RuntimeWarning
+               RuntimeWarning, stacklevel=2
                )
             self.flag_df = True
             f_original = f
@@ -2189,7 +2205,7 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
             warnings.warn(
                """2x-thru does not have the same frequency vector as the fixture-dut-fixture.
                Interpolating to fix problem.""",
-               RuntimeWarning
+               RuntimeWarning, stacklevel=2
                )
 
         # enforce Nyquist rate point
@@ -2245,7 +2261,7 @@ class IEEEP370_SE_ZC_2xThru(Deembedding):
         else:
             warnings.warn(
                "no output because no output was requested",
-               RuntimeWarning
+               RuntimeWarning, stacklevel=2
                )
 
 
@@ -2468,7 +2484,8 @@ class IEEEP370_MM_ZC_2xThru(Deembedding):
 
         # check if the frequencies match with dummy frequencies
         if ntwk.frequency != self.s2xthru.frequency:
-            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.', RuntimeWarning)
+            warnings.warn('Network frequencies dont match dummy frequencies, attempting overlap.',
+                          RuntimeWarning, stacklevel=2)
             ntwk, s2xthru = overlap_multi([ntwk, self.s2xthru])
             se_side1, se_side2 = self.split2xthru(s2xthru, self.sfix_dut_fix)
         else:
