@@ -83,12 +83,15 @@ Various Utility Functions
 
 
 """
-from typing import Callable, Union
+from __future__ import annotations
+
+from typing import Callable
+
 import numpy as npy
-from numpy import pi, unwrap, real, imag
+from numpy import imag, pi, real, unwrap
 from scipy import signal
 
-from . constants import NumberLike, INF, ALMOST_ZERO, LOG_OF_NEG, EIG_COND, EIG_MIN
+from .constants import ALMOST_ZERO, EIG_COND, EIG_MIN, INF, LOG_OF_NEG, NumberLike
 
 
 # simple conversions
@@ -264,7 +267,7 @@ def magnitude_2_db(z: NumberLike, zero_nan: bool = True):
     """
     out = 20 * npy.log10(z)
     if zero_nan:
-        return npy.nan_to_num(out, copy=False, nan=LOG_OF_NEG, neginf=-npy.inf)
+        return npy.nan_to_num(out, nan=LOG_OF_NEG, neginf=-npy.inf)
     return out
 
 mag_2_db = magnitude_2_db
@@ -288,7 +291,7 @@ def mag_2_db10(z: NumberLike, zero_nan:bool = True):
     """
     out = 10 * npy.log10(z)
     if zero_nan:
-        return npy.nan_to_num(out, copy=False, nan=LOG_OF_NEG, neginf=-npy.inf)
+        return npy.nan_to_num(out, nan=LOG_OF_NEG, neginf=-npy.inf)
     return out
 
 
@@ -718,7 +721,7 @@ def inf_to_num(x: NumberLike):
     x : Number of array_like
         Input without with +/- inf replaced by large numbers
     """
-    x = npy.nan_to_num(x, copy=False, nan=npy.nan, posinf=INF, neginf=-1*INF)
+    x = npy.nan_to_num(x, nan=npy.nan, posinf=INF, neginf=-1*INF)
     return x
 
 
@@ -869,7 +872,7 @@ def flatten_c_mat(s: NumberLike, order: str = 'F'):
     return complex2Scalar(s.flatten(order='F'))
 
 
-def rand_c(*args) -> npy.ndarray:
+def rand_c(*size) -> npy.ndarray:
     """
     Creates a complex random array of shape s.
 
@@ -884,8 +887,9 @@ def rand_c(*args) -> npy.ndarray:
     ---------
     >>> x = rf.rand_c(2,2)
     """
-    return 1-2*npy.random.rand(*args) + \
-        1j-2j*npy.random.rand(*args)
+    rng = npy.random.default_rng()
+    return 1-2*rng.random(size) + \
+        1j-2j*rng.random(size)
 
 
 
@@ -942,7 +946,13 @@ def psd2TimeDomain(f: npy.ndarray, y: npy.ndarray, windowType: str = 'hamming'):
     return timeVector, signalVector
 
 
-def rational_interp(x: npy.ndarray, y: npy.ndarray, d: int = 4, epsilon: float = 1e-9, axis: int = 0, assume_sorted: bool = False) -> Callable:
+def rational_interp(
+        x: npy.ndarray,
+        y: npy.ndarray,
+        d: int = 4,
+        epsilon: float = 1e-9,
+        axis: int = 0,
+        assume_sorted: bool = False) -> Callable:
     """
     Interpolates function using rational polynomials of degree `d`.
 
@@ -978,7 +988,8 @@ def rational_interp(x: npy.ndarray, y: npy.ndarray, d: int = 4, epsilon: float =
 
     References
     ------------
-    .. [#] M. S. Floater and K. Hormann, "Barycentric rational interpolation with no poles and high rates of approximation," Numer. Math., vol. 107, no. 2, pp. 315-331, Aug. 2007
+    .. [#] M. S. Floater and K. Hormann, "Barycentric rational interpolation with no poles and high rates of
+    approximation," Numer. Math., vol. 107, no. 2, pp. 315-331, Aug. 2007
     """
     if axis != 0:
         raise NotImplementedError("Axis other than 0 is not implemented")
@@ -1282,8 +1293,8 @@ def rsolve(A: npy.ndarray, B: npy.ndarray) -> npy.ndarray:
             npy.transpose(B, (0, 2, 1)).conj()), (0, 2, 1)).conj()
 
 def nudge_eig(mat: npy.ndarray,
-              cond: Union[float, None] = None,
-              min_eig: Union[float, None] = None) -> npy.ndarray:
+              cond: float | None = None,
+              min_eig: float | None  = None) -> npy.ndarray:
     r"""Nudge eigenvalues with absolute value smaller than
     max(cond * max(eigenvalue), min_eig) to that value.
     Can be used to avoid singularities in solving matrix equations.
