@@ -1,11 +1,13 @@
-import unittest
 import os
+import unittest
 
+import numpy as npy
 import pytest
+from numpy.testing import assert_almost_equal, assert_array_almost_equal
+
 import skrf as rf
 from skrf.media import Coaxial
-import numpy as npy
-from numpy.testing import assert_almost_equal, assert_array_almost_equal
+
 
 class MediaTestCase(unittest.TestCase):
     """
@@ -50,8 +52,9 @@ class MediaTestCase(unittest.TestCase):
         """
         # create a dummy Coaxial media for various attenuation and test the
         # resulting alpha values (real part of gamma)
-        frequency = rf.Frequency(npy.random.rand(), unit='GHz', npoints=1)
-        _att = npy.random.rand()
+        rng = npy.random.default_rng()
+        frequency = rf.Frequency(rng.random(), unit='GHz', npoints=1)
+        _att = rng.random()
         # dB/m
         coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=_att, unit='dB/m')
         assert_almost_equal(coax.gamma.real,  rf.db_2_np(_att))
@@ -117,4 +120,4 @@ class MediaTestCase(unittest.TestCase):
             R_simple = coax.Rs/(2*npy.pi)*(1/coax.a + 1/coax.b)
 
             self.assertTrue(abs(1 - coax.R[0]/dc_res) < 1e-2)
-            self.assertTrue(abs(1 - coax.R[1]/R_simple[1]) < 1e-2)
\ No newline at end of file
+            self.assertTrue(abs(1 - coax.R[1]/R_simple[1]) < 1e-2)
