@@ -43,18 +43,19 @@ NetworkSet Utilities
 
 
 """
+from __future__ import annotations
+
 import zipfile
 from io import BytesIO
 from numbers import Number
-from typing import Any, Mapping, TextIO, Union
+from typing import Any, Mapping, TextIO
 
 import numpy as npy
 from scipy.interpolate import interp1d
 
 from . import mathFunctions as mf
-from .network import (COMPONENT_FUNC_DICT, PRIMARY_PROPERTIES, Frequency,
-                      Network)
-from .util import now_string_2_dt, copy_doc
+from .network import COMPONENT_FUNC_DICT, PRIMARY_PROPERTIES, Frequency, Network
+from .util import copy_doc, now_string_2_dt
 
 try:
     from numpy.typing import ArrayLike
@@ -64,7 +65,6 @@ except ImportError:
 from . import plotting as skrf_plt
 
 
-
 class NetworkSet:
     """
     A set of Networks.
@@ -126,7 +126,7 @@ class NetworkSet:
 
     """
 
-    def __init__(self, ntwk_set: Union[list, dict] = [], name: str = None):
+    def __init__(self, ntwk_set: list | dict = None, name: str = None):
         """
         Initialize for NetworkSet.
 
@@ -138,12 +138,14 @@ class NetworkSet:
                 the name of the NetworkSet, given to the Networks returned
                 from properties of this class.
         """
+        if ntwk_set is None:
+            ntwk_set = []
         if not isinstance(ntwk_set, (list, dict)):
             raise ValueError('NetworkSet requires a list as argument')
 
         # dict is authorized for convenience
         # but if a dict is passed instead of a list -> list
-        if hasattr(ntwk_set, 'values'):
+        if isinstance(ntwk_set, dict):
             ntwk_set = list(ntwk_set.values())
 
         # did they pass a list of Networks?
@@ -160,7 +162,7 @@ class NetworkSet:
 
         ## initialization
         # we are good to go
-        self.ntwk_set = ntwk_set
+        self.ntwk_set: list[Network] = ntwk_set
         self.name = name
 
         # extract the dimensions of the set
@@ -316,10 +318,10 @@ class NetworkSet:
         NetworkSet.to_s_dict
         """
         return cls([Network(s=d[k], frequency=frequency, name=k,
-                            *args, **kwargs)  for k in d])
+                            **kwargs)  for k in d])
 
     @classmethod
-    def from_mdif(cls, file: Union[str, TextIO]) -> 'NetworkSet':
+    def from_mdif(cls, file: str | TextIO) -> NetworkSet:
         """
         Create a NetworkSet from a MDIF file.
 
@@ -342,7 +344,7 @@ class NetworkSet:
         return Mdif(file).to_networkset()
 
     @classmethod
-    def from_citi(cls, file: Union[str, TextIO]) -> 'NetworkSet':
+    def from_citi(cls, file: str | TextIO) -> NetworkSet:
         """
         Create a NetworkSet from a CITI file.
 
@@ -378,7 +380,9 @@ class NetworkSet:
             if isinstance(other, NetworkSet):
                 if len(other) != len(self):
                     raise(ValueError('Network sets must be of same length to be cascaded'))
-                return NetworkSet([getattr(self.ntwk_set[k], operator_name)(other.ntwk_set[k]) for k in range(len(self))])
+                return NetworkSet([
+                        getattr(self.ntwk_set[k], operator_name)(other.ntwk_set[k]) for k in range(len(self))
+                    ])
 
             elif isinstance(other, Network):
                 return NetworkSet([getattr(ntwk, operator_name)(other) for ntwk in self.ntwk_set])
@@ -396,7 +400,7 @@ class NetworkSet:
     def __repr__(self):
         return self.__str__()
 
-    def __getitem__(self,key):
+    def __getitem__(self, key):
         """
         Return an element of the network set.
         """
@@ -419,7 +423,7 @@ class NetworkSet:
         """
         return len(self.ntwk_set)
 
-    def __eq__(self, other: 'NetworkSet') -> bool:
+    def __eq__(self, other: NetworkSet) -> bool:
         """
         Compare the NetworkSet with another NetworkSet.
 
@@ -562,7 +566,7 @@ class NetworkSet:
             d[k] = d[k].s
         return d
 
-    def element_wise_method(self, network_method_name: str, *args, **kwargs) -> 'NetworkSet':
+    def element_wise_method(self, network_method_name: str, *args, **kwargs) -> NetworkSet:
         """
         Call a given method of each element and returns the result as
         a new NetworkSet if the output is a Network.
@@ -584,7 +588,7 @@ class NetworkSet:
         else:
             return output
 
-    def copy(self) -> 'NetworkSet':
+    def copy(self) -> NetworkSet:
         """
         Copie each network of the network set.
 
@@ -595,7 +599,7 @@ class NetworkSet:
         """
         return NetworkSet([k.copy() for k in self.ntwk_set])
 
-    def sort(self, key=lambda x: x.name, inplace: bool = True, **kwargs) -> Union[None, 'NetworkSet']:
+    def sort(self, key=lambda x: x.name, inplace: bool = True, **kwargs) -> None | NetworkSet:
         r"""
         Sort this network set.
 
@@ -645,7 +649,7 @@ class NetworkSet:
             number of samples to return (default is 1)
 
         """
-        idx = npy.random.randint(0,len(self), n)
+        idx = npy.random.default_rng().randint(0,len(self), n)
         out = [self.ntwk_set[k] for k in idx]
 
         if n ==1:
@@ -653,7 +657,7 @@ class NetworkSet:
         else:
             return out
 
-    def filter(self, s: str) -> 'NetworkSet':
+    def filter(self, s: str) -> NetworkSet:
         """
         Filter NetworkSet based on a string in `Network.name`.
 
@@ -766,7 +770,7 @@ class NetworkSet:
         return ntwk
 
     @property
-    def inv(self) -> 'NetworkSet':
+    def inv(self) -> NetworkSet:
         """
         Return the NetworkSet of inverted Networks (Network.inv()).
 
@@ -943,9 +947,9 @@ class NetworkSet:
 
     def write_mdif(self,
                    filename: str,
-                   values: Union[dict, None] = None,
-                   data_types: Union[dict, None] = None,
-                   comments = []):
+                   values: dict | None = None,
+                   data_types: dict | None = None,
+                   comments = None):
         """Convert a scikit-rf NetworkSet object to a Generalized MDIF file.
 
         Parameters
@@ -972,6 +976,8 @@ class NetworkSet:
 
         """
         from .io import Mdif
+        if comments is None:
+            comments = []
         Mdif.write(ns=self, filename=filename, values=values,
                              data_types=data_types, comments=comments)
 
@@ -1017,7 +1023,8 @@ class NetworkSet:
         x : real
             Point to evaluate the interpolated network at
         interp_kind: str
-            Specifies the kind of interpolation as a string: 'linear', 'nearest', 'zero', 'slinear', 'quadratic', 'cubic'.  Cf :class:`scipy.interpolate.interp1d` for detailed description.
+            Specifies the kind of interpolation as a string: 'linear', 'nearest', 'zero', 'slinear', 'quadratic',
+            'cubic'. See :class:`scipy.interpolate.interp1d` for detailed description.
             Default is 'linear'.
 
         Returns
@@ -1091,7 +1098,7 @@ class NetworkSet:
         return list(self.dims)
 
     @property
-    def params_values(self) -> Union[dict, None]:
+    def params_values(self) -> dict | None:
         """
         Return a dictionnary containing all parameters and their values.
 
@@ -1113,7 +1120,7 @@ class NetworkSet:
             return None
 
     @property
-    def params_types(self) -> Union[dict, None]:
+    def params_types(self) -> dict | None:
         """
         Return a dictionnary describing the data type of each parameters.
 
@@ -1133,11 +1140,11 @@ class NetworkSet:
                 try:
                     _ = [int(v) for v in values[key]]
                     data_types[key] = 'int'
-                except ValueError as e:  # not an int
+                except ValueError:  # not an int
                     try:
                         _ = [float(v) for v in values[key]]
                         data_types[key] = 'double'
-                    except ValueError as e:  # not a float -> then a string
+                    except ValueError:  # not a float -> then a string
                         data_types[key] = 'string'
 
             return data_types
@@ -1145,7 +1152,7 @@ class NetworkSet:
             return None
 
 
-    def sel(self, indexers: Mapping[Any, Any] = None) -> 'NetworkSet':
+    def sel(self, indexers: Mapping[Any, Any] = None) -> NetworkSet:
         """
         Select Network(s) in the NetworkSet from a given value of a parameter.
 
@@ -1227,7 +1234,7 @@ class NetworkSet:
 
 
     def interpolate_from_params(self, param: str, x: float,
-                                sub_params: dict={}, interp_kind: str = 'linear'):
+                                sub_params: dict=None, interp_kind: str = 'linear'):
         """
         Interpolate a Network from given parameters of NetworkSet's Networks.
 
@@ -1282,6 +1289,8 @@ class NetworkSet:
 
         """
         # checking interpolating param and values
+        if sub_params is None:
+            sub_params = {}
         if param not in self.params:
             raise ValueError(f'Parameter {param} is not found in the NetworkSet params.')
         if isinstance(x, Number):
@@ -1309,7 +1318,7 @@ class NetworkSet:
                                                       x, interp_kind)
 
         return interp_ntwk
-    
+
     @copy_doc(skrf_plt.animate)
     def animate(self, *args, **kwargs):
         skrf_plt.animate(self, *args, **kwargs)
@@ -1346,10 +1355,6 @@ class NetworkSet:
     def plot_uncertainty_decomposition(self, *args, **kwargs):
         skrf_plt.plot_uncertainty_decomposition(self, *args, **kwargs)
 
-    @copy_doc(skrf_plt.plot_uncertainty_bounds_s)
-    def plot_uncertainty_bounds_s(self, *args, **kwargs):
-        skrf_plt.plot_uncertainty_bounds_s(self, *args, **kwargs)
-
     @copy_doc(skrf_plt.plot_logsigma)
     def plot_logsigma(self, *args, **kwargs):
         skrf_plt.plot_logsigma(self, *args, **kwargs)
@@ -1357,7 +1362,7 @@ class NetworkSet:
     @copy_doc(skrf_plt.signature)
     def signature(self, *args, **kwargs):
         skrf_plt.signature(self, *args, **kwargs)
-        
+
 
 def func_on_networks(ntwk_list, func, attribute='s',name=None, *args,\
         **kwargs):
@@ -1397,7 +1402,7 @@ def func_on_networks(ntwk_list, func, attribute='s',name=None, *args,\
     data_matrix = npy.array([getattr(ntwk, attribute) for ntwk in ntwk_list])
 
     new_ntwk = ntwk_list[0].copy()
-    new_ntwk.s = func(data_matrix,axis=0,*args,**kwargs)
+    new_ntwk.s = func(data_matrix,axis=0,**kwargs)
 
     if name is not None:
         new_ntwk.name = name
