@@ -55,9 +55,8 @@ from __future__ import annotations
 
 import os
 import warnings
-from functools import partialmethod
 from numbers import Number
-from typing import TYPE_CHECKING, Callable, List, Tuple, Union
+from typing import TYPE_CHECKING, Callable
 
 try:
     import matplotlib as mpl
@@ -75,7 +74,7 @@ import numpy as npy
 from . import mathFunctions as mf
 from .constants import NumberLike
 from .frequency import Frequency
-from .util import axes_kwarg, copy_doc, now_string_2_dt, partial_with_docs
+from .util import axes_kwarg, now_string_2_dt
 
 if TYPE_CHECKING:
     from . import Network, NetworkSet
@@ -83,6 +82,17 @@ if TYPE_CHECKING:
 SI_PREFIXES_ASCII = 'yzafpnum kMGTPEZY'
 SI_CONVERSION = {key: 10**((8-i)*3) for i, key in enumerate(SI_PREFIXES_ASCII)}
 
+def _get_label_str(netw: Network, param: str, m: int, n: int) -> str:
+    label_string = ""
+    if netw.name is not None:
+        label_string += f"{netw.name}, "
+
+    if plt.rcParams['text.usetex']:
+        label_string += f"${param}_{{{netw._fmt_trace_name(m,n)}}}$"
+    else:
+        label_string += f"{param}{netw._fmt_trace_name(m,n)}"
+    return label_string
+
 
 def scale_frequency_ticks(ax: plt.Axes, funit: str):
     """
@@ -113,8 +123,8 @@ def scale_frequency_ticks(ax: plt.Axes, funit: str):
 
 @axes_kwarg
 def smith(smithR: Number = 1, chart_type: str = 'z', draw_labels: bool = False,
-          border: bool = False, ax: Union[plt.Axes, None] = None, ref_imm: float = 1.0,
-          draw_vswr: Union[List, bool, None] = None):
+          border: bool = False, ax: plt.Axes | None = None, ref_imm: float = 1.0,
+          draw_vswr: list | bool | None = None):
     """
     Plot the Smith chart of a given radius.
 
@@ -337,9 +347,9 @@ def smith(smithR: Number = 1, chart_type: str = 'z', draw_labels: bool = False,
 
 
 def plot_rectangular(x: NumberLike, y: NumberLike,
-                     x_label: Union[str, None] = None, y_label: Union[str, None] = None,
-                     title: Union[str, None] = None, show_legend: bool = True,
-                     axis: str = 'tight', ax: Union[plt.Axes, None] = None,
+                     x_label: str | None = None, y_label: str | None = None,
+                     title: str | None = None, show_legend: bool = True,
+                     axis: str = 'tight', ax: plt.Axes | None = None,
                      *args, **kwargs):
     r"""
     Plot rectangular data and optionally label axes.
@@ -395,9 +405,9 @@ def plot_rectangular(x: NumberLike, y: NumberLike,
 
 
 def plot_polar(theta: NumberLike, r: NumberLike,
-               x_label: Union[str, None] = None, y_label: Union[str, None] = None,
-               title: Union[str, None] = None, show_legend: bool = True,
-               axis_equal: bool = False, ax: Union[plt.Axes, None] = None,
+               x_label: str | None = None, y_label: str | None = None,
+               title: str | None = None, show_legend: bool = True,
+               axis_equal: bool = False, ax: plt.Axes | None = None,
                *args, **kwargs):
     r"""
     Plot polar data on a polar plot and optionally label axes.
@@ -446,6 +456,7 @@ def plot_polar(theta: NumberLike, r: NumberLike,
             warnings.warn(
                 f"Projection of the Axes passed as `ax` is not 'polar' but is {ax.name}." +
                 "See Matplotlib documentation to create a polar plot or call this function without the `ax` parameter."
+                , stacklevel=2
             )
 
     ax.plot(theta, r, *args, **kwargs)
@@ -474,7 +485,7 @@ def plot_polar(theta: NumberLike, r: NumberLike,
 def plot_complex_rectangular(z: NumberLike,
                              x_label: str = 'Real', y_label: str = 'Imag',
                              title: str = 'Complex Plane', show_legend: bool = True,
-                             axis: str = 'equal', ax: Union[plt.Axes, None] = None,
+                             axis: str = 'equal', ax: plt.Axes | None = None,
                              **kwargs):
     r"""
     Plot complex data on the complex plane.
@@ -512,9 +523,9 @@ def plot_complex_rectangular(z: NumberLike,
 
 
 def plot_complex_polar(z: NumberLike,
-                       x_label: Union[str, None] = None, y_label: Union[str, None] = None,
-                       title: Union[str, None] = None, show_legend: bool = True,
-                       axis_equal: bool = False, ax: Union[plt.Axes, None] = None,
+                       x_label: str | None = None, y_label: str | None = None,
+                       title: str | None = None, show_legend: bool = True,
+                       axis_equal: bool = False, ax: plt.Axes | None = None,
                        **kwargs):
     r"""
     Plot complex data in polar format.
@@ -552,8 +563,8 @@ def plot_complex_polar(z: NumberLike,
 
 def plot_smith(s: NumberLike, smith_r: float = 1, chart_type: str = 'z',
                x_label: str = 'Real', y_label: str = 'Imaginary', title: str = 'Complex Plane',
-               show_legend: bool = True, axis: str = 'equal', ax: Union[plt.Axes, None] = None,
-               force_chart: bool = False, draw_vswr: Union[List, bool, None] = None, draw_labels: bool = False,
+               show_legend: bool = True, axis: str = 'equal', ax: plt.Axes | None = None,
+               force_chart: bool = False, draw_vswr: list | bool | None = None, draw_labels: bool = False,
                **kwargs):
     r"""
     Plot complex data on smith chart.
@@ -615,7 +626,7 @@ def plot_smith(s: NumberLike, smith_r: float = 1, chart_type: str = 'z',
         plt.draw()
 
 
-def subplot_params(ntwk, param: str = 's', proj: str = 'db',
+def subplot_params(ntwk: Network, param: str = 's', proj: str = 'db',
                    size_per_port: int = 4, newfig: bool = True,
                    add_titles: bool = True, keep_it_tight: bool = True,
                    subplot_kw: dict = None,
@@ -661,16 +672,16 @@ def subplot_params(ntwk, param: str = 's', proj: str = 'db',
         axs = npy.array(f.get_axes())
 
     for ports,ax in zip(ntwk.port_tuples, axs.flatten()):
-        plot_func = ntwk.__getattribute__('plot_%s_%s'%(param, proj))
+        plot_func = ntwk.__getattribute__(f'plot_{param}_{proj}')
         plot_func(m=ports[0], n=ports[1], ax=ax, **kwargs)
         if add_titles:
-            ax.set_title('%s%i%i'%(param.upper(),ports[0]+1, ports[1]+1))
+            ax.set_title(f"{param.upper()}{ntwk._fmt_trace_name(ports[0], ports[1])}")
     if keep_it_tight:
        plt.tight_layout()
     return f, axs
 
 
-def shade_bands(edges: NumberLike, y_range: Union[Tuple, None] = None,
+def shade_bands(edges: NumberLike, y_range: tuple | None = None,
                 cmap: str = 'prism', **kwargs):
     r"""
     Shades frequency bands.
@@ -708,7 +719,7 @@ def shade_bands(edges: NumberLike, y_range: Union[Tuple, None] = None,
     plt.axis(axis)
 
 
-def save_all_figs(dir: str = './', format: Union[None, List[str]] = None,
+def save_all_figs(dir: str = './', format: None | list[str] = None,
                   replace_spaces: bool = True, echo: bool = True):
     """
     Save all open Figures to disk.
@@ -747,7 +758,7 @@ saf = save_all_figs
 
 @axes_kwarg
 def add_markers_to_lines(ax: plt.Axes = None,
-                         marker_list: List = None,
+                         marker_list: list = None,
                          markevery: int = 10):
     """
     Add markers to existing lings on a plot.
@@ -794,7 +805,7 @@ def legend_off(ax: plt.Axes = None):
     ax.legend_.set_visible(0)
 
 @axes_kwarg
-def scrape_legend(n: Union[int, None] = None,
+def scrape_legend(n: int | None = None,
                   ax:plt.Axes = None):
     """
     Scrape a legend with redundant labels.
@@ -872,7 +883,7 @@ def plot_vector(a: complex, off: complex = 0+0j, **kwargs):
            angles='xy', scale=1, **kwargs)
 
 
-def colors() -> List[str]:
+def colors() -> list[str]:
     """
     Return the list of colors of the rcParams color cycle.
 
@@ -937,7 +948,7 @@ def plot_reciprocity(netw: Network, db=False, *args, **kwargs):
         for n in range(netw.nports):
             if m > n:
                 if 'label' not in kwargs.keys():
-                    kwargs['label'] = 'ports %i%i' % (m, n)
+                    kwargs['label'] = f"ports {netw._fmt_trace_name(m, n)}"
                 y = netw.reciprocity[:, m, n].flatten()
                 y = mf.complex_2_db(y) if db else npy.abs(y)
                 netw.frequency.plot(y, *args, **kwargs)
@@ -968,7 +979,7 @@ def plot_reciprocity2(netw: Network, db=False, *args, **kwargs):
         for n in range(netw.nports):
             if m > n:
                 if 'label' not in kwargs.keys():
-                    kwargs['label'] = 'ports %i%i' % (m, n)
+                    kwargs['label'] = f"ports {netw._fmt_trace_name(m, n)}"
                 y = netw.reciprocity2[:, m, n].flatten()
                 if db:
                     y = mf.complex_2_db(y)
@@ -979,7 +990,7 @@ def plot_reciprocity2(netw: Network, db=False, *args, **kwargs):
         plt.draw()
 
 
-def plot_s_db_time(netw: Network, *args, window: Union[str, float, Tuple[str, float]]=('kaiser', 6),
+def plot_s_db_time(netw: Network, *args, window: str | float | tuple[str, float]=('kaiser', 6),
         normalize: bool = True, center_to_dc: bool = None, **kwargs):
     return netw.windowed(window, normalize, center_to_dc).plot_s_time_db(*args,**kwargs)
 
@@ -1059,19 +1070,7 @@ def plot_s_smith(netw: Network, m=None, n=None,r=1, ax=None, show_legend=True,\
             # set the legend label for this trace to the networks name if it
             # exists, and they didnt pass a name key in the kwargs
             if generate_label:
-                if netw.name is None:
-                    if plt.rcParams['text.usetex']:
-                        label_string = '$S_{'+repr(m+1) + repr(n+1)+'}$'
-                    else:
-                        label_string = 'S'+repr(m+1) + repr(n+1)
-                else:
-                    if plt.rcParams['text.usetex']:
-                        label_string = netw.name+', $S_{'+repr(m+1) + \
-                                repr(n+1)+'}$'
-                    else:
-                        label_string = netw.name+', S'+repr(m+1) + repr(n+1)
-
-                kwargs['label'] = label_string
+                kwargs['label'] = _get_label_str(netw, "S", m, n)
 
             # plot the desired attribute vs frequency
             if len (ax.patches) == 0:
@@ -1145,8 +1144,8 @@ def stylely(rc_dict: dict = None, style_file: str = 'skrf.mplstyle'):
 
 
 # Network Set Plotting Commands
-def animate(self: NetworkSet, attr: str = 's_deg', ylims: Tuple = (-5, 5),
-            xlims: Union[Tuple, None] = None, show: bool = True,
+def animate(self: NetworkSet, attr: str = 's_deg', ylims: tuple = (-5, 5),
+            xlims: tuple | None = None, show: bool = True,
             savefigs: bool = False, dir_: str = '.', *args, **kwargs):
     r"""
     Animate a property of the networkset.
@@ -1228,9 +1227,9 @@ def animate(self: NetworkSet, attr: str = 's_deg', ylims: Tuple = (-5, 5),
 @axes_kwarg
 def plot_uncertainty_bounds_component(
         self: NetworkSet, attribute: str,
-        m: Union[int, None] = None, n: Union[int, None] = None,
+        m: int | None = None, n: int | None = None,
         type: str = 'shade', n_deviations: int = 3,
-        alpha: float = .3, color_error: Union[str, None] = None,
+        alpha: float = .3, color_error: str | None = None,
         markevery_error: int = 20, ax: plt.Axes = None,
         ppf: bool = None, kwargs_error: dict = None,
         **kwargs):
@@ -1315,7 +1314,7 @@ def plot_uncertainty_bounds_component(
                 upper_bound = ppf(upper_bound)
                 lower_bound = ppf(lower_bound)
                 lower_bound[npy.isnan(lower_bound)] = min(lower_bound)
-                if ppf in [mf.magnitude_2_db, mf.mag_2_db]:  # quickfix of wrong ylabels due to usage of ppf for *_db plots
+                if ppf in [mf.magnitude_2_db, mf.mag_2_db]:  # fix of wrong ylabels due to usage of ppf for *_db plots
                     if attribute == 's_mag':
                         plot_attribute = 's_db'
                     elif attribute == 's_time_mag':
@@ -1349,7 +1348,7 @@ def plot_uncertainty_bounds_component(
 @axes_kwarg
 def plot_minmax_bounds_component(self: NetworkSet, attribute: str, m: int = 0, n: int = 0,
                                  type: str = 'shade', n_deviations: int = 3,
-                                 alpha: float = .3, color_error: Union[str, None] = None,
+                                 alpha: float = .3, color_error: str | None = None,
                                  markevery_error: int = 20, ax: plt.Axes = None,
                                  ppf: bool = None, kwargs_error: dict = None,
                                  **kwargs):
@@ -1513,64 +1512,13 @@ def plot_uncertainty_decomposition(self: NetworkSet, m: int = 0, n: int = 0):
 
     """
     if self.name is not None:
-        plt.title(r'Uncertainty Decomposition: %s $S_{%i%i}$'%(self.name,m,n))
+        plt.title(f"Uncertainty Decomposition: {self.name} $S_{{{self.ntwk_set[0]._fmt.trace_name(m,n)}}}$")
     self.std_s.plot_s_mag(label='Distance', m=m,n=n)
     self.std_s_re.plot_s_mag(label='Real',  m=m,n=n)
     self.std_s_im.plot_s_mag(label='Imaginary',  m=m,n=n)
     self.std_s_mag.plot_s_mag(label='Magnitude',  m=m,n=n)
     self.std_s_arcl.plot_s_mag(label='Arc-length',  m=m,n=n)
 
-def plot_uncertainty_bounds_s(self: NetworkSet, multiplier: float = 200, *args, **kwargs):
-    """
-    Plot complex uncertainty bounds plot on smith chart.
-
-    This function plots the complex uncertainty of a NetworkSet
-    as circles on the smith chart. At each frequency a circle
-    with radii proportional to the complex standard deviation
-    of the set at that frequency is drawn. Due to the fact that
-    the `markersize` argument is in pixels, the radii can scaled by
-    the input argument  `multiplier`.
-
-    default kwargs are
-        {
-        'marker':'o',
-        'color':'b',
-        'mew':0,
-        'ls':'',
-        'alpha':.1,
-        'label':None,
-        }
-
-    Parameters
-    ----------
-    multiplier : float
-        controls the circle sizes, by multiples of the standard
-        deviation.
-
-    """
-    default_kwargs = {
-        'marker':'o',
-        'color':'b',
-        'mew':0,
-        'ls':'',
-        'alpha':.1,
-        'label':None,
-        }
-    default_kwargs.update(**kwargs)
-
-    if plt.isinteractive():
-        was_interactive = True
-        plt.interactive(0)
-    else:
-        was_interactive = False
-
-    [self.mean_s[k].plot_s_smith(*args, ms = self.std_s[k].s_mag*multiplier, **default_kwargs) for k in range(len(self[0]))]
-
-    if was_interactive:
-        plt.interactive(1)
-    plt.draw()
-    plt.show()
-
 def plot_logsigma(self: NetworkSet, label_axis: bool = True, *args,**kwargs):
     r"""
     Plot the uncertainty for the set in units of log-sigma.
@@ -1591,8 +1539,8 @@ def plot_logsigma(self: NetworkSet, label_axis: bool = True, *args,**kwargs):
 
 
 def signature(self: NetworkSet, m: int = 0, n: int = 0, component: str = 's_mag',
-              vmax: Union[Number, None] = None, vs_time: bool = False,
-              cbar_label: Union[str, None] = None,
+              vmax: Number | None = None, vs_time: bool = False,
+              cbar_label: str | None = None,
               *args, **kwargs):
     r"""
     Visualization of a NetworkSet.
@@ -1797,21 +1745,7 @@ def plot_prop_complex(netw: Network, prop_name: str,
             # name if it exists, and they didn't pass a name key in
             # the kwargs
             if gen_label:
-                if netw.name is None:
-                    if plt.rcParams['text.usetex']:
-                        label_string = '$%s_{%i%i}$'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                    else:
-                        label_string = '%s%i%i'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                else:
-                    if plt.rcParams['text.usetex']:
-                        label_string = netw.name+', $%s_{%i%i}$'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                    else:
-                        label_string = netw.name+', %s%i%i'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                kwargs['label'] = label_string
+                kwargs['label'] = _get_label_str(netw, prop_name[0].upper(), m, n)
 
             # plot the desired attribute vs frequency
             plot_complex_rectangular(
@@ -1876,25 +1810,10 @@ def plot_prop_polar(netw: Network, prop_name: str,
             # name if it exists, and they didn't pass a name key in
             # the kwargs
             if gen_label:
-                if netw.name is None:
-                    if plt.rcParams['text.usetex']:
-                        label_string = '$%s_{%i%i}$'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                    else:
-                        label_string = '%s%i%i'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                else:
-                    if plt.rcParams['text.usetex']:
-                        label_string = netw.name+', $%s_{%i%i}$'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                    else:
-                        label_string = netw.name+', %s%i%i'%\
-                        (prop_name[0].upper(),m+1,n+1)
-                kwargs['label'] = label_string
+                kwargs['label'] = _get_label_str(netw, prop_name[0].upper(), m, n)
 
             # plot the desired attribute vs frequency
             plot_complex_polar(
                 z = getattr(netw,prop_name)[:,m,n],
                 show_legend = show_legend, ax = ax,
                 **kwargs)
-
